@@ -25,9 +25,8 @@
 #include "box_data_list_find.h"
 #include "box_data_details_find.h"
 
-/**
-  *@author Murray Cumming
-  */
+namespace Glom
+{
 
 class Notebook_Find : public Notebook_Glom
 {
@@ -35,21 +34,29 @@ public:
   Notebook_Find();
   virtual ~Notebook_Find();
 
-  virtual void init_db_details(const Glib::ustring& strDatabaseName, const Glib::ustring& strTableName);
+  virtual bool init_db_details(const Glib::ustring& table_name);
+
+  void set_current_view(Notebook_Data::dataview view);
+
+  /** Emitted when the user has entered a find critera that
+   * should be used to find and display records.
+   * @param find_criteria The SQL where clause.
+   */
+  sigc::signal<void, Glib::ustring> signal_find_criteria;
 
-  //Signals:
-  //where_clause.
-  sigc::signal<void, Glib::ustring> signal_find;
-  
 protected:
 
+
   //Signal handlers:
-  virtual void on_page_find(Glib::ustring strWhereClause);
+  virtual void on_page_find_criteria(const Glib::ustring& where_clause);
 
   //Member widgets:
   Box_Data_List_Find m_Box_List;
   Box_Data_Details_Find m_Box_Details;
 
+  guint m_iPage_Details, m_iPage_List;
 };
 
+} //namespace Glom
+
 #endif
